/*
  Copyright 2020 Kakao Corp.

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */
package com.kakao.sdk.partner.auth

import android.content.Context
import com.kakao.sdk.auth.LoginClient
import com.kakao.sdk.auth.model.OAuthToken

/**
 * 기본 브라우저의 카카오계정 쿠키 유무와 관계 없이
 * 카카오계정 로그인 페이지를 먼저 호출하여 사용자를 인증한 후 토큰을 발급 받습니다.
 *
 * @param context CustomTabs를 실행하기 위한 현재 Activity context
 * @param accountParameters 카카오계정 로그인 페이지 호출 시 ID fill-in 을 위한 'email' 등, 임의의 파라미터를 추가할 수 있습니다.
 * @param callback 발급 받은 [OAuthToken] 반환.
 */
@JvmOverloads
fun LoginClient.loginWithKakaoAccount(
    context: Context,
    accountParameters: Map<String, String>,
    callback: (token: OAuthToken?, error: Throwable?) -> Unit
) {
    authCodeClient.authorizeWithKakaoAccount(context, forceAccountLogin = true, accountParameters = accountParameters) { code, error ->
        if (error != null) {
            callback(null, error)
        } else {
            authApiClient.issueAccessToken(code!!) { token, error ->
                callback(token, error)
            }
        }
    }
}
